<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<context>
    <name>AboutDialog</name>
    <message>
        <source>cuteTube-QML - 0.5.1</source>
        <translation type="obsolete">cuteTube-QML - 0.5.1 - Suomennos: d-iivil</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.6.1</source>
        <translation type="obsolete">cuteTube-QML - 0.6.1 - Suomennos: d-iivil</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.6.3</source>
        <translation type="obsolete">cuteTube-QML - 0.6.3 - Suomennos: d-iivil</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.6.5</source>
        <translation type="obsolete">cuteTube-QML - 0.6.5 - Suomennos: d-iivil</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.0</source>
        <translation type="obsolete">cuteTube-QML - 0.7.0 - Suomennos: d-iivil</translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="44"/>
        <source>cuteTube-QML - 0.7.1</source>
        <translation type="unfinished">cuteTube-QML - 0.7.1 - Suomennos: d-iivil</translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="56"/>
        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation>Monipuolinen YouTube -clientti Nokia N900:lle. Tämä on QML käyttävä kehitysversio. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
    </message>
</context>
<context>
    <name>AccountDetailsDialog</name>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="10"/>
        <location filename="../AccountDetailsDialog.qml" line="26"/>
        <source>New Account</source>
        <translation>Uusi tili</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="15"/>
        <source>Edit Account</source>
        <translation>Muokkaa tiliä</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="46"/>
        <source>Database error. Unable to save account</source>
        <translation>Tietokantavirhe. Tilin tallennus epäonnistui</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="82"/>
        <source>Username</source>
        <translation>Käyttäjätunnus</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="95"/>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="108"/>
        <source>Default?</source>
        <translation>Oletus?</translation>
    </message>
</context>
<context>
    <name>AccountsDialog</name>
    <message>
        <location filename="../AccountsDialog.qml" line="79"/>
        <source>YouTube Accounts</source>
        <translation>YouTube -tilit</translation>
    </message>
</context>
<context>
    <name>AddCommentDialog</name>
    <message>
        <location filename="../AddCommentDialog.qml" line="6"/>
        <source>Add Comment</source>
        <translation>Lisää kommentti</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="15"/>
        <source>Share Via </source>
        <translation>Jaa</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="60"/>
        <source>Title</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="74"/>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="111"/>
        <source>Message</source>
        <translation>Viesti</translation>
    </message>
</context>
<context>
    <name>AddToPlaylistDialog</name>
    <message>
        <location filename="../AddToPlaylistDialog.qml" line="31"/>
        <source>Add To Playlist</source>
        <translation>Lisää soittolistalle</translation>
    </message>
</context>
<context>
    <name>ArchiveListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Monivalinta</translation>
    </message>
    <message>
        <source>Delete from archive</source>
        <translation type="obsolete">Poista kirjastosta</translation>
    </message>
    <message>
        <source>Delete from device</source>
        <translation type="obsolete">Poista laitteesta</translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="27"/>
        <source>Deleted from archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="30"/>
        <location filename="../ArchiveListView.qml" line="47"/>
        <source>Unable to delete from archive</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BusyDialog</name>
    <message>
        <location filename="../BusyDialog.qml" line="50"/>
        <source>Loading...</source>
        <translation>Ladataan...</translation>
    </message>
</context>
<context>
    <name>ChangeUserDialog</name>
    <message>
        <location filename="../ChangeUserDialog.qml" line="50"/>
        <source>Change Current User</source>
        <translation>Vaihda käyttäjätiliä</translation>
    </message>
</context>
<context>
    <name>CommentsDelegate</name>
    <message>
        <location filename="../CommentsDelegate.qml" line="20"/>
        <location filename="../CommentsDelegate.qml" line="22"/>
        <source>By </source>
        <translation>Kirjoittaja: </translation>
    </message>
    <message>
        <location filename="../CommentsDelegate.qml" line="21"/>
        <location filename="../CommentsDelegate.qml" line="23"/>
        <source> on </source>
        <translation>milloin: </translation>
    </message>
</context>
<context>
    <name>ConfirmExitDialog</name>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="47"/>
        <source>Hold it!</source>
        <translation>Odota!</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="58"/>
        <source>cuteTube is currently downloading. Do you really want to exit?</source>
        <translation>cuteTube on parhaillaan lataamassa vidota. Haluatko varmasti poistua?</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="71"/>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="81"/>
        <source>No</source>
        <translation>Ei</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <source>English</source>
        <translation type="obsolete">Englanti</translation>
    </message>
    <message>
        <source>German</source>
        <translation type="obsolete">Saksa</translation>
    </message>
    <message>
        <source>Finnish</source>
        <translation type="obsolete">Suomi</translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation type="obsolete">Alankomaiden</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="obsolete">Puolalainen</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="188"/>
        <source>Video deleted from device</source>
        <translation>Video poistettu laitteesta</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="191"/>
        <source>Unable to delete video</source>
        <translation>Videon poisto epäonnistui</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="195"/>
        <source>Video not found</source>
        <translation>Videota ei löytynyt</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="250"/>
        <source>Copied to clipboard</source>
        <translation>Kopioitu leikepöydälle</translation>
    </message>
</context>
<context>
    <name>DownloadListDelegate</name>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Pysäytetty</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">Jonossa</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Epäonnistunut</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Ladataan</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Epäonnistui</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Ladataan</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Pysäytetty</translation>
    </message>
</context>
<context>
    <name>FileChooserDialog</name>
    <message>
        <location filename="../FileChooserDialog.qml" line="29"/>
        <source>Choose Video File</source>
        <translation>Valitse tiedosto</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Asetukset</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation type="obsolete">Tilit</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">Tietoja</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="119"/>
        <source>My Channel</source>
        <translation>Oma kanavani</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="143"/>
        <source>Most Recent</source>
        <translation>Tuoreimmat</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="167"/>
        <source>Most Viewed</source>
        <translation>Katsotuimmat</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="191"/>
        <source>Archive</source>
        <translation>Kirjasto</translation>
    </message>
</context>
<context>
    <name>MenuBar</name>
    <message>
        <source>Menu</source>
        <translation type="obsolete">Valikko</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="obsolete">Takaisin</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Poistu</translation>
    </message>
</context>
<context>
    <name>MyAccountView</name>
    <message>
        <source>Upload video</source>
        <translation type="obsolete">Lataa video</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="81"/>
        <source>My Uploads</source>
        <translation>Omat lataukset</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="87"/>
        <source>Uploads</source>
        <translation>Lataukset</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="105"/>
        <source>My Favourites</source>
        <translation>Omat suosikit</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="111"/>
        <source>Favourites</source>
        <translation>Suosikit</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="135"/>
        <source>Playlists</source>
        <translation>Soittolistat</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="159"/>
        <source>Subscriptions</source>
        <translation>Syötteet</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="174"/>
        <source>Signed in as:</source>
        <translation>Kirjautunut:</translation>
    </message>
</context>
<context>
    <name>NewPlaylistDialog</name>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="34"/>
        <source>New Playlist</source>
        <translation>Uusi soittolista</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="46"/>
        <source>Title</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="59"/>
        <source>Description (optional)</source>
        <translation>Kuvasu (valinnainen)</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="71"/>
        <source>Private?</source>
        <translation>Yksityinen?</translation>
    </message>
</context>
<context>
    <name>NoAccountDialog</name>
    <message>
        <location filename="../NoAccountDialog.qml" line="60"/>
        <source>Hi there!</source>
        <translation>Terve!</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="71"/>
        <source>My name&apos;s Cutey. My buddy Clippy tells me it&apos;s the first time you&apos;ve used cuteTube. Would you like to add a YouTube account?</source>
        <translation>Nimeni on Cutey. Kaverini Clippy kertoi että tämä on eka kerta kun käytät cuteTubea. Haluaisitko lisätä YouTube -tilin?</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="84"/>
        <source>Yes</source>
        <translation>Kyllä</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="98"/>
        <source>Go Away</source>
        <translation>En, mene pois</translation>
    </message>
</context>
<context>
    <name>NotificationArea</name>
    <message>
        <location filename="../NotificationArea.qml" line="50"/>
        <source>No active downloads</source>
        <translation>Ei aktiivisia latauksia</translation>
    </message>
    <message>
        <location filename="../NotificationArea.qml" line="145"/>
        <source>Downloads</source>
        <translation>Lataukset</translation>
    </message>
</context>
<context>
    <name>OAuthDialog</name>
    <message>
        <location filename="../OAuthDialog.qml" line="8"/>
        <source>Authorisation For </source>
        <translation>Vahvistus: </translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="27"/>
        <source>Error obtaining facebook authorisation</source>
        <translation>Virhe vahvistettaessa facebook -tiliä</translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="117"/>
        <source>Enter pin code</source>
        <translation>Syötä salasana</translation>
    </message>
</context>
<context>
    <name>PlaylistDelegate</name>
    <message>
        <location filename="../PlaylistDelegate.qml" line="31"/>
        <source> videos</source>
        <translation>videot</translation>
    </message>
</context>
<context>
    <name>PlaylistVideosView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Monivalinta</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Lataa video</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Lataa audio</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Lisää suosikkeihin</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Lisää soittolistalle</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Kopioi leikepöydälle</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="59"/>
        <source>Video(s) deleted from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="80"/>
        <source>No videos found</source>
        <translation>Ei videoita</translation>
    </message>
</context>
<context>
    <name>PlaylistsView</name>
    <message>
        <location filename="../PlaylistsView.qml" line="58"/>
        <source>New playlist created</source>
        <translation>Uusi soittolista luotu</translation>
    </message>
    <message>
        <source>New playlist</source>
        <translation type="obsolete">Uusi soittolista</translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="106"/>
        <source>No playlists found</source>
        <translation>Ei soittolistoja</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <location filename="../ProxyDialog.qml" line="30"/>
        <source>Network Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="44"/>
        <source>Host (e.g. 192.168.100.1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="51"/>
        <source>Port (e.g. 8080)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Date</source>
        <translation>Pvm</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Relevance</source>
        <translation>Sopivuus</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Rating</source>
        <translation>Arvio</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Views</source>
        <translation>Katseluja</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="181"/>
        <source>Order by:</source>
        <translation>Järjestä: </translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../SettingsDialog.qml" line="37"/>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>Mobile</source>
        <translation>Mobiili</translation>
    </message>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Korkea laatu</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="39"/>
        <source>Automatically</source>
        <translation>Automaattisesti</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="39"/>
        <source>Manually</source>
        <translation>Manuaalisesti</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <source>On</source>
        <translation>On</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <source>Off</source>
        <translation>Pois</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Automatic</source>
        <translation>Automaattinen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Landscape</source>
        <translation>Vaaka</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Portrait</source>
        <translation>Pysty</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Most recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Most viewed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Latest subscription videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>My uploads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>My favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="162"/>
        <location filename="../SettingsDialog.qml" line="504"/>
        <source>Media Player</source>
        <translation>Mediasoitin</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Light</source>
        <translation>Vaalea</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="37"/>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>High quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>360p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>480p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>720p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Dark</source>
        <translation>Tumma</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>English</source>
        <translation>Englanti</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>German</source>
        <translation>Saksa</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Finnish</source>
        <translation>Suomi</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Italian</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Dutch</source>
        <translation>Alankomaiden</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Polish</source>
        <translation>Puolalainen</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">Jonossa</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Pysäytetty</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="105"/>
        <source>Your settings have been saved</source>
        <translation>Asetukset tallennettu</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="110"/>
        <location filename="../SettingsDialog.qml" line="153"/>
        <source>Download Path</source>
        <translation>Latauspolku</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="112"/>
        <source>Download Location</source>
        <translation>Lataussijainti</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="120"/>
        <location filename="../SettingsDialog.qml" line="171"/>
        <source>Network Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="144"/>
        <location filename="../SettingsDialog.qml" line="394"/>
        <source>Playback Quality</source>
        <translation>Toistolaatu</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="147"/>
        <location filename="../SettingsDialog.qml" line="412"/>
        <source>Download Quality</source>
        <translation>Latauksen laatu</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="150"/>
        <location filename="../SettingsDialog.qml" line="430"/>
        <source>Start Downloads</source>
        <translation>Käynnistä lataukset</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="156"/>
        <location filename="../SettingsDialog.qml" line="468"/>
        <source>Safe Search</source>
        <translation>Turvallinen Haku</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="159"/>
        <location filename="../SettingsDialog.qml" line="486"/>
        <source>Screen Orientation</source>
        <translation>Käyttöliittymän suunta</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="165"/>
        <location filename="../SettingsDialog.qml" line="339"/>
        <location filename="../SettingsDialog.qml" line="522"/>
        <source>Theme</source>
        <translation>Teema</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="168"/>
        <location filename="../SettingsDialog.qml" line="348"/>
        <location filename="../SettingsDialog.qml" line="540"/>
        <source>Language</source>
        <translation>Kieli</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="174"/>
        <location filename="../SettingsDialog.qml" line="623"/>
        <source>Widget Feed One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="177"/>
        <location filename="../SettingsDialog.qml" line="643"/>
        <source>Widget Feed Two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="180"/>
        <location filename="../SettingsDialog.qml" line="663"/>
        <source>Widget Feed Three</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="183"/>
        <location filename="../SettingsDialog.qml" line="683"/>
        <source>Widget Feed Four</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="192"/>
        <source>Your saved searches have been cleared</source>
        <translation>Tallennetut hakusanat on tyhjennetty</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="195"/>
        <source>Database error. Unable to clear searches</source>
        <translation>Tietokantavirhe. Hakuja ei tyhjennetty</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="242"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="275"/>
        <source>Network proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="283"/>
        <source>Playback quality</source>
        <translation>Toistolaatu</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="291"/>
        <source>Download quality</source>
        <translation>Latauksien laatu</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="299"/>
        <source>Start downloads</source>
        <translation>Aloita lataukset</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="307"/>
        <source>Download location</source>
        <translation>Latauskansio</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="315"/>
        <source>Safe search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="323"/>
        <source>Screen orientation</source>
        <translation>Käyttöliittymän suunta</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="331"/>
        <source>Media player</source>
        <translation>Mediasoitin</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="367"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="572"/>
        <source>Feed One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="580"/>
        <source>Feed Two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="588"/>
        <source>Feed Three</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="596"/>
        <source>Feed Four</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="698"/>
        <source>Clear saved searches</source>
        <translation>Tyhjennä hakusanat</translation>
    </message>
</context>
<context>
    <name>Sharing</name>
    <message>
        <location filename="../../../sharing.cpp" line="78"/>
        <source>Error - Server repsonse is: </source>
        <translation>Virhe - Palvelin vastasi: </translation>
    </message>
</context>
<context>
    <name>SubscriptionsView</name>
    <message>
        <location filename="../SubscriptionsView.qml" line="36"/>
        <source>Latest Subscriptions Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="45"/>
        <source>You have unsubscribed to this channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have unsubscribed to &apos;</source>
        <translation type="obsolete">Olet tilannut seuraavat syötteet: </translation>
    </message>
    <message>
        <source>Latest Subscription Videos</source>
        <translation type="obsolete">Viimeisimmät videot syötteestä</translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="104"/>
        <source>No subscriptions found</source>
        <translation>Ei syötteitä</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../UploadDialog.qml" line="8"/>
        <source>Cars &amp; Vehicles</source>
        <translation>Autot &amp; Kulkuneuvot</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="8"/>
        <source>Comedy</source>
        <translation>Komedia</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="9"/>
        <source>Education</source>
        <translation>Koulutus</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="9"/>
        <location filename="../UploadDialog.qml" line="19"/>
        <source>Entertainment</source>
        <translation>Viihde</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="10"/>
        <source>Film and Animation</source>
        <translation>Elokuvat ja animaatiot</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="10"/>
        <source>Gaming</source>
        <translation>Pelit</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>Howto &amp; Style</source>
        <translation>Ohjeet ja tyylit</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>Music</source>
        <translation>Musiikki</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>News &amp; Politics</source>
        <translation>Uutiset ja politiikka</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="12"/>
        <source>Non-profits &amp; Activism</source>
        <translation>Aktivismi &amp; Anarkia</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="12"/>
        <source>People &amp; Blogs</source>
        <translation>Ihmiset ja blogit</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <source>Pets &amp; Animals</source>
        <translation>Eläimet</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <source>Science &amp; Technology</source>
        <translation>Tiede ja teknologia</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="14"/>
        <source>Sport</source>
        <translation>Urheilu</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="14"/>
        <source>Travel &amp; Events</source>
        <translation>Matkustus</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="35"/>
        <location filename="../UploadDialog.qml" line="215"/>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="114"/>
        <source>Upload Video</source>
        <translation>Lataa video</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="138"/>
        <source>File</source>
        <translation>Tiedosto</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="147"/>
        <location filename="../UploadDialog.qml" line="223"/>
        <source>None chosen</source>
        <translation>Ei valittuja</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="163"/>
        <source>Title</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="176"/>
        <source>Description (optional)</source>
        <translation>Kuvaus (valinnainen)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="188"/>
        <source>Tags (seperated by commas)</source>
        <translation>Tagit (eroittele pilkulla)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="201"/>
        <source>Private?</source>
        <translation>Yksityinen?</translation>
    </message>
</context>
<context>
    <name>UploadProgressDialog</name>
    <message>
        <location filename="../UploadProgressDialog.qml" line="6"/>
        <source>Starting upload</source>
        <translation>Aloitetaan lataus</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="30"/>
        <source>Upload Progress</source>
        <translation>Lataus käynnissä</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="42"/>
        <source>Filename</source>
        <translation>Tiedosto</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="57"/>
        <source>Title</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <location filename="../UploadProgressDialog.qml" line="97"/>
        <location filename="../UploadProgressDialog.qml" line="115"/>
        <source>Upload is in progress</source>
        <translation>Lataus on käynnissä</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Abort</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
</context>
<context>
    <name>UserInfoDialog</name>
    <message>
        <location filename="../UserInfoDialog.qml" line="127"/>
        <source>Subscribers</source>
        <translation>Tilaajat</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="141"/>
        <source>Videos</source>
        <translation>Videot</translation>
    </message>
</context>
<context>
    <name>UserVideosView</name>
    <message>
        <location filename="../UserVideosView.qml" line="117"/>
        <source>You have subscribed to &apos;</source>
        <translation>Olet tilannut syötteen: </translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="121"/>
        <source>You have unsubscribed to &apos;</source>
        <translation>Olet perunut syötteen: </translation>
    </message>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Monivalinta</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Lataa video</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Lataa audio</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Lisää suosikkeihin</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Lisää soittolistalle</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Kopioi leikepöydälle</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="141"/>
        <source>No videos found</source>
        <translation>Ei videoita</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="200"/>
        <source>Subscribers</source>
        <translation>Tilaajat</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="214"/>
        <source>Videos</source>
        <translation>Videot</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="237"/>
        <source>Unsubscribe</source>
        <translation>Peru tilaus</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="237"/>
        <source>Subscribe</source>
        <translation>Tilaa</translation>
    </message>
</context>
<context>
    <name>VideoInfoView</name>
    <message>
        <location filename="../VideoInfoView.qml" line="15"/>
        <source>No description</source>
        <translation>Ei kuvausta</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="92"/>
        <source>Your comment has been added</source>
        <translation>Kommenttisi tallennettiin</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="95"/>
        <source>Your rating has been added</source>
        <translation>Arviosi tallennettiin</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="102"/>
        <source>Video shared on facebook</source>
        <translation>Video jaettu facebookkiin</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Lisää suosikkeihin</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Lisää soittolistalle</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Kopioi leikepöydälle</translation>
    </message>
    <message>
        <source>Share via facebook</source>
        <translation type="obsolete">Jaa facebookin kautta</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="443"/>
        <location filename="../VideoInfoView.qml" line="467"/>
        <location filename="../VideoInfoView.qml" line="579"/>
        <source>You are not signed in to a YouTube account</source>
        <translation>Et ole kirjautunut YouTubeen</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="244"/>
        <source>Info</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="283"/>
        <source>Comments</source>
        <translation>Kommentit</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="322"/>
        <source>Related</source>
        <translation>Liittyvät</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="413"/>
        <location filename="../VideoInfoView.qml" line="416"/>
        <source>By </source>
        <translation>Kirjoittaja: </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="415"/>
        <location filename="../VideoInfoView.qml" line="418"/>
        <source> on </source>
        <translation> milloin: </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="484"/>
        <source>Views</source>
        <translation>Katseluja</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="498"/>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="514"/>
        <source>Tags</source>
        <translation>Tagit</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="524"/>
        <source>No tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="591"/>
        <source>No comments</source>
        <translation>Ei kommentteja</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="591"/>
        <source> comments</source>
        <translation>kommentit</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="684"/>
        <source>No related videos</source>
        <translation>Ei liittyviä videoita</translation>
    </message>
</context>
<context>
    <name>VideoListDelegate</name>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source>By </source>
        <translation>Kirjoittaja: </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source> on </source>
        <translation>milloin: </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="102"/>
        <source>Views</source>
        <translation>Katseluja</translation>
    </message>
</context>
<context>
    <name>VideoListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Monivalinta</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Lataa video</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Lataa audio</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Lisää suosikkeihin</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Lisää soittolistalle</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Kopioi leikepöydälle</translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="70"/>
        <source>Video(s) deleted from favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="92"/>
        <source>No videos found</source>
        <translation>Ei videoita</translation>
    </message>
</context>
<context>
    <name>VideoPlaybackView</name>
    <message>
        <source>Error: Unable to retrieve video</source>
        <translation type="obsolete">Virhe: videon lataus epäonnistui</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>Error: Unable to retrieve video</source>
        <translation type="obsolete">Virhe: videon lataus epäonnistui</translation>
    </message>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Ei videoita</translation>
    </message>
</context>
<context>
    <name>XHamsterInfoView</name>
    <message>
        <source>Info</source>
        <translation type="obsolete">Tietoa</translation>
    </message>
    <message>
        <source>Related</source>
        <translation type="obsolete">Liittyvät</translation>
    </message>
    <message>
        <source>By </source>
        <translation type="obsolete">Kirjoittaja: </translation>
    </message>
    <message>
        <source> on </source>
        <translation type="obsolete">milloin: </translation>
    </message>
    <message>
        <source>Views </source>
        <translation type="obsolete">Katselut</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="obsolete">Tagit</translation>
    </message>
</context>
<context>
    <name>XHamsterListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Monivalinta</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Lataa video</translation>
    </message>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Ei videoita</translation>
    </message>
</context>
<context>
    <name>YouJizzInfoView</name>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Kopioi leikepöydälle</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Tietoa</translation>
    </message>
    <message>
        <source>Related</source>
        <translation type="obsolete">Liittyvät</translation>
    </message>
    <message>
        <source>Views </source>
        <translation type="obsolete">Katseluja</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="obsolete">Tagit</translation>
    </message>
</context>
<context>
    <name>YouJizzListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Monivalinta</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Lataa video</translation>
    </message>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Ei videoita</translation>
    </message>
</context>
<context>
    <name>YouTube</name>
    <message>
        <location filename="../../../youtube.cpp" line="40"/>
        <source>Error obtaining access token</source>
        <translation>Virhe haettaessa varmennetta</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="55"/>
        <source>Authentication failed</source>
        <translation>Varmennus epäonnistui</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="59"/>
        <source>You are signed in to YouTube as &apos;</source>
        <translation>Olet kirjautunut YouTubeen tilillä: </translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="121"/>
        <location filename="../../../youtube.cpp" line="227"/>
        <source>Error - Server repsonse is: </source>
        <translation>Virhe - Palvelin vastasi: </translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="171"/>
        <location filename="../../../youtube.cpp" line="179"/>
        <source>Upload aborted</source>
        <translation>Lataus keskeytetty</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="186"/>
        <source>Upload interrupted. Attempting to resume...</source>
        <translation>Lataus keskeytyi. Kokeilen jatkaa...</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="190"/>
        <source>Upload failed</source>
        <translation>Lataus epäonnistui</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="196"/>
        <source>Upload is completed</source>
        <translation>Lataus valmistui</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="388"/>
        <source>Error: Unable to retrieve video</source>
        <translation>Virhe: videon lataus epäonnistui</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dark</source>
        <translation type="obsolete">Tumma</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="obsolete">Vaalea</translation>
    </message>
    <message>
        <location filename="../main.qml" line="111"/>
        <source>Video(s) added to download queue</source>
        <translation>Video(t) lisätty latausjonoon</translation>
    </message>
    <message>
        <location filename="../main.qml" line="122"/>
        <source>Audio track(s) added to download queue</source>
        <translation>Audio(t) lisätty latausjonoon</translation>
    </message>
    <message>
        <location filename="../main.qml" line="153"/>
        <source>Video added to favourites</source>
        <translation>Video lisätty suosikkeihin</translation>
    </message>
    <message>
        <location filename="../main.qml" line="154"/>
        <source>Video added to playlist</source>
        <translation>Video lisätty soittolistalle</translation>
    </message>
    <message>
        <location filename="../main.qml" line="162"/>
        <source>New playlist created</source>
        <translation>Uusi soittolista luotu</translation>
    </message>
    <message>
        <source>Converting</source>
        <translation type="obsolete">Muunnetaan</translation>
    </message>
    <message>
        <location filename="../main.qml" line="207"/>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="212"/>
        <source>Conversion of &apos;</source>
        <translation>Muunto: </translation>
    </message>
    <message>
        <location filename="../main.qml" line="212"/>
        <source>&apos; failed</source>
        <translation> epäonnistui</translation>
    </message>
    <message>
        <location filename="../main.qml" line="228"/>
        <source>High quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="228"/>
        <source>Mobile</source>
        <translation type="unfinished">Mobiili</translation>
    </message>
    <message>
        <location filename="../main.qml" line="228"/>
        <source>360p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="228"/>
        <source>480p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="228"/>
        <source>720p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="229"/>
        <source>Queued</source>
        <translation>Jonossa</translation>
    </message>
    <message>
        <location filename="../main.qml" line="229"/>
        <source>Paused</source>
        <translation>Keskeytetty</translation>
    </message>
    <message>
        <location filename="../main.qml" line="229"/>
        <source>Downloading</source>
        <translation type="unfinished">Ladataan</translation>
    </message>
    <message>
        <location filename="../main.qml" line="229"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="396"/>
        <source>Most Recent</source>
        <translation>Tuoreimmat</translation>
    </message>
    <message>
        <location filename="../main.qml" line="397"/>
        <source>Most Viewed</source>
        <translation>Katsotuimmat</translation>
    </message>
</context>
<context>
    <name>mainscripts</name>
    <message>
        <source>Media Player</source>
        <translation type="obsolete">Mediasoitin</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="143"/>
        <source>My Channel</source>
        <translation>Oma kanavani</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="158"/>
        <source>Archive</source>
        <translation>Arkisto</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="197"/>
        <source>My Playlists</source>
        <translation>Omat soittolistani</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="207"/>
        <source>My Subscriptions</source>
        <translation>Omat tilaukseni</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="220"/>
        <source>Video Info</source>
        <translation>Videon tiedot</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="230"/>
        <source>Video Playback</source>
        <translation>Videon toisto</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="obsolete">Lataukset</translation>
    </message>
    <message>
        <source>date</source>
        <translation type="obsolete">pvm</translation>
    </message>
    <message>
        <source>views</source>
        <translation type="obsolete">katselut</translation>
    </message>
    <message>
        <source>relevance</source>
        <translation type="obsolete">liittyvät</translation>
    </message>
    <message>
        <source>rating</source>
        <translation type="obsolete">arvio</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="243"/>
        <source>Search </source>
        <translation>Haku</translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Korkea laatu</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Pysäytetty</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="obsolete">Automaattinen</translation>
    </message>
    <message>
        <source>Media Player</source>
        <translation type="obsolete">Mediasoitin</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="obsolete">Pvm</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="obsolete">Tumma</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Englanti</translation>
    </message>
</context>
<context>
    <name>xtube</name>
    <message>
        <source>date</source>
        <translation type="obsolete">pvm</translation>
    </message>
    <message>
        <source>views</source>
        <translation type="obsolete">katselut</translation>
    </message>
    <message>
        <source>rating</source>
        <translation type="obsolete">arvio</translation>
    </message>
    <message>
        <source>Search </source>
        <translation type="obsolete">Haku</translation>
    </message>
    <message>
        <source>Video Info</source>
        <translation type="obsolete">Videon tiedot</translation>
    </message>
    <message>
        <source>relevance</source>
        <translation type="obsolete">liittyvät</translation>
    </message>
</context>
</TS>
